@@ -25,7 +25,7 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: cpu.c,v 1.316 2005/08/16 05:37:09 debug Exp $
+ *  $Id: cpu.c,v 1.321 2005/10/03 01:07:40 debug Exp $
  *
  *  Common routines for CPU emulation. (Not specific to any CPU type.)
  */
@@ -244,6 +244,8 @@ void cpu_functioncall_trace(struct cpu *cpu, uint64_t f)
 		fatal("cpu%i:\t", cpu->cpu_id);
 
 	cpu->trace_tree_depth ++;
+	if (cpu->trace_tree_depth > 100)
+		cpu->trace_tree_depth = 100;
 	for (i=0; i<cpu->trace_tree_depth; i++)
 		fatal("  ");
 
@@ -307,8 +309,8 @@ void cpu_create_or_reset_tc(struct cpu *cpu)
 	 *  There might be other translation pointers that still point to
 	 *  within the translation_cache region. Let's invalidate those too:
 	 */
-	if (cpu->invalidate_code_translation_caches != NULL)
-		cpu->invalidate_code_translation_caches(cpu);
+	if (cpu->invalidate_code_translation != NULL)
+		cpu->invalidate_code_translation(cpu, 0, INVALIDATE_ALL);
 }
 
 
@@ -653,6 +655,18 @@ void cpu_init(void)
 	add_cpu_family(arm_cpu_family_init, ARCH_ARM);
 #endif
 
+#ifdef ENABLE_AVR
+	add_cpu_family(avr_cpu_family_init, ARCH_AVR);
+#endif
+
+#ifdef ENABLE_HPPA
+	add_cpu_family(hppa_cpu_family_init, ARCH_HPPA);
+#endif
+
+#ifdef ENABLE_I960
+	add_cpu_family(i960_cpu_family_init, ARCH_I960);
+#endif
+
 #ifdef ENABLE_IA64
 	add_cpu_family(ia64_cpu_family_init, ARCH_IA64);
 #endif
@@ -669,6 +683,10 @@ void cpu_init(void)
 	add_cpu_family(ppc_cpu_family_init, ARCH_PPC);
 #endif
 
+#ifdef ENABLE_SH
+	add_cpu_family(sh_cpu_family_init, ARCH_SH);
+#endif
+
 #ifdef ENABLE_SPARC
 	add_cpu_family(sparc_cpu_family_init, ARCH_SPARC);
 #endif
