@@ -28,7 +28,7 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: cpu_sparc.h,v 1.8 2005/08/16 05:37:13 debug Exp $
+ *  $Id: cpu_sparc.h,v 1.9 2005/08/28 20:16:24 debug Exp $
  */
 
 #include "misc.h"
@@ -107,8 +107,8 @@ struct sparc_cpu {
 /*  cpu_sparc.c:  */
 void sparc_update_translation_table(struct cpu *cpu, uint64_t vaddr_page,
 	unsigned char *host_page, int writeflag, uint64_t paddr_page);
-void sparc_invalidate_translation_caches_paddr(struct cpu *cpu, uint64_t paddr);
-void sparc_invalidate_code_translation_caches(struct cpu *cpu);
+void sparc_invalidate_translation_caches_paddr(struct cpu *cpu, uint64_t, int);
+void sparc_invalidate_code_translation(struct cpu *cpu, uint64_t, int);
 int sparc_memory_rw(struct cpu *cpu, struct memory *mem, uint64_t vaddr,
 	unsigned char *data, size_t len, int writeflag, int cache_flags);
 int sparc_cpu_family_init(struct cpu_family *);
