@@ -28,7 +28,7 @@
  *  SUCH DAMAGE.
  *
  *
- *  $Id: devices.h,v 1.176 2005/08/05 09:11:49 debug Exp $
+ *  $Id: devices.h,v 1.184 2005/10/03 01:07:48 debug Exp $
  *
  *  Memory mapped devices.
  *
@@ -243,6 +243,25 @@ struct vfb_data *dev_fb_init(struct machine *machine, struct memory *mem,
 	uint64_t baseaddr, int vfb_type, int visible_xsize, int visible_ysize,
 	int xsize, int ysize, int bit_depth, char *name);
 
+/*  dev_footbridge:  */
+#define N_FOOTBRIDGE_TIMERS		4
+struct footbridge_data {
+	struct pci_data *pcibus;
+
+	int		console_handle;
+
+	int		timer_tick_countdown[N_FOOTBRIDGE_TIMERS];
+	uint32_t	timer_load[N_FOOTBRIDGE_TIMERS];
+	uint32_t	timer_value[N_FOOTBRIDGE_TIMERS];
+	uint32_t	timer_control[N_FOOTBRIDGE_TIMERS];
+
+	uint32_t        irq_status;
+	uint32_t        irq_enable;
+
+	uint32_t        fiq_status;
+	uint32_t        fiq_enable;
+}; 
+
 /*  dev_gt.c:  */
 #define	DEV_GT_LENGTH			0x1000
 int dev_gt_access(struct cpu *cpu, struct memory *mem, uint64_t relative_addr,
@@ -599,11 +618,6 @@ int dev_vr41xx_access(struct cpu *cpu, struct memory *mem,
 struct vr41xx_data *dev_vr41xx_init(struct machine *machine,
 	struct memory *mem, int cpumodel);
 
-/*  dev_wdc.c:  */
-#define	DEV_WDC_LENGTH			0x8
-int dev_wdc_access(struct cpu *cpu, struct memory *mem, uint64_t relative_addr, unsigned char *data, size_t len, int writeflag, void *);
-void dev_wdc_init(struct machine *machine, struct memory *mem, uint64_t baseaddr, int irq_nr, int base_drive);
-
 /*  dev_wdsc.c:  */
 #define	DEV_WDSC_NREGS			0x100		/*  8-bit register select  */
 #define	DEV_WDSC_LENGTH			0x10
